==> istio-model-1.0.1-sources.jar: me/snowdrop/istio/api/mixer/v1/PreconditionResultFluent.java <==
package me.snowdrop.istio.api.mixer.v1;

import me.snowdrop.istio.api.Status;
import com.fasterxml.jackson.annotation.JsonPropertyDescription;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import me.snowdrop.istio.api.StatusFluent;
import java.lang.Integer;
import java.lang.Deprecated;
import javax.validation.Valid;
import java.lang.Long;
import me.snowdrop.istio.api.StatusBuilder;
import java.lang.Boolean;

public interface PreconditionResultFluent<A extends PreconditionResultFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildReferencedAttributes instead.
 * @return The buildable object.
 */
@Deprecated public ReferencedAttributes getReferencedAttributes();
    public ReferencedAttributes buildReferencedAttributes();
    public A withReferencedAttributes(ReferencedAttributes referencedAttributes);
    public Boolean hasReferencedAttributes();
    public PreconditionResultFluent.ReferencedAttributesNested<A> withNewReferencedAttributes();
    public PreconditionResultFluent.ReferencedAttributesNested<A> withNewReferencedAttributesLike(ReferencedAttributes item);
    public PreconditionResultFluent.ReferencedAttributesNested<A> editReferencedAttributes();
    public PreconditionResultFluent.ReferencedAttributesNested<A> editOrNewReferencedAttributes();
    public PreconditionResultFluent.ReferencedAttributesNested<A> editOrNewReferencedAttributesLike(ReferencedAttributes item);
    
/**
 * This method has been deprecated, please use method buildRouteDirective instead.
 * @return The buildable object.
 */
@Deprecated public RouteDirective getRouteDirective();
    public RouteDirective buildRouteDirective();
    public A withRouteDirective(RouteDirective routeDirective);
    public Boolean hasRouteDirective();
    public PreconditionResultFluent.RouteDirectiveNested<A> withNewRouteDirective();
    public PreconditionResultFluent.RouteDirectiveNested<A> withNewRouteDirectiveLike(RouteDirective item);
    public PreconditionResultFluent.RouteDirectiveNested<A> editRouteDirective();
    public PreconditionResultFluent.RouteDirectiveNested<A> editOrNewRouteDirective();
    public PreconditionResultFluent.RouteDirectiveNested<A> editOrNewRouteDirectiveLike(RouteDirective item);
    
/**
 * This method has been deprecated, please use method buildStatus instead.
 * @return The buildable object.
 */
@Deprecated public me.snowdrop.istio.api.Status getStatus();
    public me.snowdrop.istio.api.Status buildStatus();
    public A withStatus(me.snowdrop.istio.api.Status status);
    public Boolean hasStatus();
    public PreconditionResultFluent.ApiStatusNested<A> withNewApiStatus();
    public PreconditionResultFluent.ApiStatusNested<A> withNewStatusLike(me.snowdrop.istio.api.Status item);
    public PreconditionResultFluent.ApiStatusNested<A> editApiStatus();
    public PreconditionResultFluent.ApiStatusNested<A> editOrNewStatus();
    public PreconditionResultFluent.ApiStatusNested<A> editOrNewStatusLike(me.snowdrop.istio.api.Status item);
    public Long getValidDuration();
    public A withValidDuration(Long validDuration);
    public Boolean hasValidDuration();
    public A withNewValidDuration(String arg1);
    public A withNewValidDuration(long arg1);
    public Integer getValidUseCount();
    public A withValidUseCount(Integer validUseCount);
    public Boolean hasValidUseCount();
    public A withNewValidUseCount(String arg1);
    public A withNewValidUseCount(int arg1);

    public interface ReferencedAttributesNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ReferencedAttributesFluent<PreconditionResultFluent.ReferencedAttributesNested<N>>{

        
    public N and();    public N endReferencedAttributes();
}
    public interface RouteDirectiveNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,RouteDirectiveFluent<PreconditionResultFluent.RouteDirectiveNested<N>>{

        
    public N and();    public N endRouteDirective();
}
    public interface ApiStatusNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,StatusFluent<PreconditionResultFluent.ApiStatusNested<N>>{

        
    public N and();    public N endApiStatus();
}


}

==> istio-model-1.1.1-sources.jar: me/snowdrop/istio/api/mixer/v1/PreconditionResultFluent.java <==
package me.snowdrop.istio.api.mixer.v1;

import me.snowdrop.istio.api.Status;
import com.fasterxml.jackson.annotation.JsonPropertyDescription;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import me.snowdrop.istio.api.StatusFluent;
import java.lang.Integer;
import java.lang.Deprecated;
import me.snowdrop.istio.api.StatusBuilder;
import java.lang.Boolean;

public interface PreconditionResultFluent<A extends PreconditionResultFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildReferencedAttributes instead.
 * @return The buildable object.
 */
@Deprecated public ReferencedAttributes getReferencedAttributes();
    public ReferencedAttributes buildReferencedAttributes();
    public A withReferencedAttributes(ReferencedAttributes referencedAttributes);
    public Boolean hasReferencedAttributes();
    public PreconditionResultFluent.ReferencedAttributesNested<A> withNewReferencedAttributes();
    public PreconditionResultFluent.ReferencedAttributesNested<A> withNewReferencedAttributesLike(ReferencedAttributes item);
    public PreconditionResultFluent.ReferencedAttributesNested<A> editReferencedAttributes();
    public PreconditionResultFluent.ReferencedAttributesNested<A> editOrNewReferencedAttributes();
    public PreconditionResultFluent.ReferencedAttributesNested<A> editOrNewReferencedAttributesLike(ReferencedAttributes item);
    
/**
 * This method has been deprecated, please use method buildRouteDirective instead.
 * @return The buildable object.
 */
@Deprecated public RouteDirective getRouteDirective();
    public RouteDirective buildRouteDirective();
    public A withRouteDirective(RouteDirective routeDirective);
    public Boolean hasRouteDirective();
    public PreconditionResultFluent.RouteDirectiveNested<A> withNewRouteDirective();
    public PreconditionResultFluent.RouteDirectiveNested<A> withNewRouteDirectiveLike(RouteDirective item);
    public PreconditionResultFluent.RouteDirectiveNested<A> editRouteDirective();
    public PreconditionResultFluent.RouteDirectiveNested<A> editOrNewRouteDirective();
    public PreconditionResultFluent.RouteDirectiveNested<A> editOrNewRouteDirectiveLike(RouteDirective item);
    
/**
 * This method has been deprecated, please use method buildStatus instead.
 * @return The buildable object.
 */
@Deprecated public Status getStatus();
    public Status buildStatus();
    public A withStatus(Status status);
    public Boolean hasStatus();
    public PreconditionResultFluent.StatusNested<A> withNewStatus();
    public PreconditionResultFluent.StatusNested<A> withNewStatusLike(Status item);
    public PreconditionResultFluent.StatusNested<A> editStatus();
    public PreconditionResultFluent.StatusNested<A> editOrNewStatus();
    public PreconditionResultFluent.StatusNested<A> editOrNewStatusLike(Status item);
    public Integer getValidDuration();
    public A withValidDuration(Integer validDuration);
    public Boolean hasValidDuration();
    public Integer getValidUseCount();
    public A withValidUseCount(Integer validUseCount);
    public Boolean hasValidUseCount();

    public interface ReferencedAttributesNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ReferencedAttributesFluent<PreconditionResultFluent.ReferencedAttributesNested<N>>{

        
    public N and();    public N endReferencedAttributes();
}
    public interface RouteDirectiveNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,RouteDirectiveFluent<PreconditionResultFluent.RouteDirectiveNested<N>>{

        
    public N and();    public N endRouteDirective();
}
    public interface StatusNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,StatusFluent<PreconditionResultFluent.StatusNested<N>>{

        
    public N and();    public N endStatus();
}


}
